@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,9 +15,11 @@
 #
 import proto  # type: ignore
 
-
 __protobuf__ = proto.module(
-    package="google.cloud.websecurityscanner.v1", manifest={"CrawledUrl",},
+    package="google.cloud.websecurityscanner.v1",
+    manifest={
+        "CrawledUrl",
+    },
 )
 
 
@@ -38,9 +40,18 @@ class CrawledUrl(proto.Message):
             used to visit the URL.
     """
 
-    http_method = proto.Field(proto.STRING, number=1,)
-    url = proto.Field(proto.STRING, number=2,)
-    body = proto.Field(proto.STRING, number=3,)
+    http_method = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    url = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    body = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
