@@ -502,6 +502,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1alpha
 
             def sample_create_scan_config():
@@ -511,7 +518,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 # Initialize request argument(s)
                 scan_config = websecurityscanner_v1alpha.ScanConfig()
                 scan_config.display_name = "display_name_value"
-                scan_config.starting_urls = ['starting_urls_value_1', 'starting_urls_value_2']
+                scan_config.starting_urls = ['starting_urls_value1', 'starting_urls_value2']
 
                 request = websecurityscanner_v1alpha.CreateScanConfigRequest(
                     parent="parent_value",
@@ -615,6 +622,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1alpha
 
             def sample_delete_scan_config():
@@ -700,6 +714,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1alpha
 
             def sample_get_scan_config():
@@ -798,6 +819,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1alpha
 
             def sample_list_scan_configs():
@@ -908,6 +936,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1alpha
 
             def sample_update_scan_config():
@@ -917,7 +952,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 # Initialize request argument(s)
                 scan_config = websecurityscanner_v1alpha.ScanConfig()
                 scan_config.display_name = "display_name_value"
-                scan_config.starting_urls = ['starting_urls_value_1', 'starting_urls_value_2']
+                scan_config.starting_urls = ['starting_urls_value1', 'starting_urls_value2']
 
                 request = websecurityscanner_v1alpha.UpdateScanConfigRequest(
                     scan_config=scan_config,
@@ -1023,6 +1058,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1alpha
 
             def sample_start_scan_run():
@@ -1120,6 +1162,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1alpha
 
             def sample_get_scan_run():
@@ -1217,6 +1266,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1alpha
 
             def sample_list_scan_runs():
@@ -1326,6 +1382,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1alpha
 
             def sample_stop_scan_run():
@@ -1423,6 +1486,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1alpha
 
             def sample_list_crawled_urls():
@@ -1532,6 +1602,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1alpha
 
             def sample_get_finding():
@@ -1630,6 +1707,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1alpha
 
             def sample_list_findings():
@@ -1750,6 +1834,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1alpha
 
             def sample_list_finding_type_stats():
