@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,9 +17,11 @@ import proto  # type: ignore
 
 from google.cloud.websecurityscanner_v1alpha.types import finding
 
-
 __protobuf__ = proto.module(
-    package="google.cloud.websecurityscanner.v1alpha", manifest={"FindingTypeStats",},
+    package="google.cloud.websecurityscanner.v1alpha",
+    manifest={
+        "FindingTypeStats",
+    },
 )
 
 
@@ -35,8 +37,15 @@ class FindingTypeStats(proto.Message):
             finding type.
     """
 
-    finding_type = proto.Field(proto.ENUM, number=1, enum=finding.Finding.FindingType,)
-    finding_count = proto.Field(proto.INT32, number=2,)
+    finding_type = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=finding.Finding.FindingType,
+    )
+    finding_count = proto.Field(
+        proto.INT32,
+        number=2,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
