@@ -507,6 +507,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             def sample_create_scan_config():
@@ -516,7 +523,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 # Initialize request argument(s)
                 scan_config = websecurityscanner_v1beta.ScanConfig()
                 scan_config.display_name = "display_name_value"
-                scan_config.starting_urls = ['starting_urls_value_1', 'starting_urls_value_2']
+                scan_config.starting_urls = ['starting_urls_value1', 'starting_urls_value2']
 
                 request = websecurityscanner_v1beta.CreateScanConfigRequest(
                     parent="parent_value",
@@ -619,6 +626,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             def sample_delete_scan_config():
@@ -704,6 +718,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             def sample_get_scan_config():
@@ -801,6 +822,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             def sample_list_scan_configs():
@@ -911,6 +939,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             def sample_update_scan_config():
@@ -920,7 +955,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 # Initialize request argument(s)
                 scan_config = websecurityscanner_v1beta.ScanConfig()
                 scan_config.display_name = "display_name_value"
-                scan_config.starting_urls = ['starting_urls_value_1', 'starting_urls_value_2']
+                scan_config.starting_urls = ['starting_urls_value1', 'starting_urls_value2']
 
                 request = websecurityscanner_v1beta.UpdateScanConfigRequest(
                     scan_config=scan_config,
@@ -1025,6 +1060,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             def sample_start_scan_run():
@@ -1123,6 +1165,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             def sample_get_scan_run():
@@ -1221,6 +1270,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             def sample_list_scan_runs():
@@ -1330,6 +1386,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             def sample_stop_scan_run():
@@ -1428,6 +1491,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             def sample_list_crawled_urls():
@@ -1537,6 +1607,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             def sample_get_finding():
@@ -1635,6 +1712,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             def sample_list_findings():
@@ -1755,6 +1839,13 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import websecurityscanner_v1beta
 
             def sample_list_finding_type_stats():
